@@ -1,8 +1,8 @@
 use anyhow::Result as AnyResult;
 
 use cosmwasm_std::{to_binary, Addr, ContractInfoResponse, Decimal};
-use cw3::Status;
 use cw_multi_test::{AppResponse, Contract, ContractWrapper, Executor};
+use tg3::Status;
 use tg4::{Member, Tg4ExecuteMsg};
 use tg_bindings::TgradeMsg;
 use tg_bindings_test::{TgradeApp, UpgradePlan};
@@ -57,10 +57,10 @@ impl SuiteBuilder {
         }
     }
 
-    pub fn with_group_member(mut self, addr: &str, weight: u64) -> Self {
+    pub fn with_group_member(mut self, addr: &str, points: u64) -> Self {
         self.group_members.push(Member {
             addr: addr.to_owned(),
-            weight,
+            points,
         });
         self
     }
@@ -162,7 +162,7 @@ pub struct Suite {
 }
 
 impl Suite {
-    fn propose(
+    pub fn propose(
         &mut self,
         executor: &str,
         title: &str,
